=========
camminapy
=========


Workflow:

.. code-block:: bash

   poetry version patch
   poetry publish --build
   make doc
   pre-commit run --all
   git commit -am "Update doc."
   git push





Install via ``pip``:

.. code-block:: bash

   pip install camminapy



Install via ``poetry``:

.. code-block:: bash

   poetry add camminapy
